@@ -350,6 +350,7 @@ def add_user_as_admin(repo, answers, headers, user):
     else:
         print(f"unable to add {user} as admin to the repo {repo} due to error {response.content.decode()}")
 
+
 def remove_user_as_admin(repo, answers, headers, user):
     print(f"Removing user {user} as adming to repo {repo}")
     source_org = answers.get("source_github_org")
@@ -363,6 +364,46 @@ def remove_user_as_admin(repo, answers, headers, user):
         print(f"unable to remove {user} as admin to the repo {repo} due to error {response.content.decode()}")
 
 
+def add_branch_protection_main(repo, answers, headers):
+    try:
+
+        target_org = answers.get("target_github_org")
+        team_slug = answers.get("target_team_name")
+
+        url = f"https://api.github.com/repos/{target_org}/{repo}/branches/main/protection"
+
+        payload = json.dumps({
+            "required_status_checks": {
+                "strict": True,
+                "contexts": [
+                    "continuous-integration/jenkins/pr-merge",
+                    "continuous-integration/jenkins/branch"
+                ]
+            },
+            "enforce_admins": False,
+            "required_pull_request_reviews": {
+                "dismissal_restrictions": {
+                    "teams": [
+                        team_slug
+                    ]
+                },
+                "dismiss_stale_reviews": True,
+                "require_code_owner_reviews": True,
+                "required_approving_review_count": 2
+            },
+            "restrictions": None
+        })
+        headers['Accept'] = 'application/vnd.github.luke-cage-preview+json'
+
+        response = s.put(url, headers=headers, data=payload)
+
+        if response.status_code == 200:
+            print("Updated branch protection rules")
+
+    except Exception as ex:
+        print("Updating Branch protection rules Failed ")
+
+
 def transfer_repo(repo, answers, user_found):
     print("\nTransferring " + repo + " to target organization")
     source_org = answers.get("source_github_org")
@@ -386,6 +427,10 @@ def transfer_repo(repo, answers, user_found):
                 is_transfer_success = transfer_repo_to_targetorg(repo, answers, headers)
                 if is_transfer_success:
                     print(f"Transfer completed for repo {repo}")
+                    # add status checks
+
+                    # add branch protection rules
+                    add_branch_protection_main(repo, answers, headers)
                     make_team_admin_writers(repo, answers, headers)
                     make_repo_internal(repo, answers, headers)
                     remove_user_as_admin(repo, answers, headers, user_found)
