@@ -30,7 +30,7 @@ def get_jobs(jenkins_answers):
     server = jenkins.Jenkins(jenkins_url, username=username, password=token)
 
     credentialsId = jenkins_answers.get("new_credentials_id")
-    jobs = server.get_jobs(folder_depth=0)
+    jobs = server.get_jobs(folder_depth=5)
     is_prompt_user = True
     for job in jobs:
         if job.get("_class") in ("org.jenkinsci.plugins.workflow.multibranch.WorkflowMultiBranchProject",
@@ -44,28 +44,28 @@ def get_jobs(jenkins_answers):
             if credentialsId.strip() != "":
                 config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentialsId}</credentialsId>",
                                 config)
-            job_name = job.get("name")
+            # job_name = job.get("name")
 
-            change_name = [
-
-                {
-                    'type': 'confirm',
-                    'name': 'change_name',
-                    'message': f"Change the bmx job name {job_name} to team_prefix.<oldname>?"
-                }
-            ]
-
-            change_name_answers = prompt(change_name, style=style)
-
-            if change_name_answers.get("change_name"):
-                job_match = re.findall(r'<displayName>.*</displayName>', config)
-                if len(job_match)>0:
-                    job_name = job_match[0].replace("displayName", "").replace("<>", "").replace("</>", "")
-
-                    new_job_name = f"{team_prefix}.{job_name}"
-                    config = re.sub("<displayName>.*</displayName>", f"<displayName>{new_job_name}</displayName>", config)
-                else:
-                    print("unable to change name")
+            # change_name = [
+            #
+            #     {
+            #         'type': 'confirm',
+            #         'name': 'change_name',
+            #         'message': f"Change the bmx job name {job_name} to team_prefix.<oldname>?"
+            #     }
+            # ]
+            #
+            # change_name_answers = prompt(change_name, style=style)
+            #
+            # if change_name_answers.get("change_name"):
+            #     job_match = re.findall(r'<displayName>.*</displayName>', config)
+            #     if len(job_match)>0:
+            #         job_name = job_match[0].replace("displayName", "").replace("<>", "").replace("</>", "")
+            #
+            #         new_job_name = f"{team_prefix}.{job_name}"
+            #         config = re.sub("<displayName>.*</displayName>", f"<displayName>{new_job_name}</displayName>", config)
+            #     else:
+            #         print("unable to change name")
 
             with open(job.get("name"), "w") as outfile:
                 outfile.write(config)
